Skip to contents

A silent check: unlike find_odiff(), it never offers to install odiff, so it is safe to use in skip conditions and scripts.

Usage

odiff_available()

Value

Logical TRUE if odiff is found and executable, FALSE otherwise.

Examples

odiff_available()
#> [1] TRUE