A silent check: unlike find_odiff(), it never offers to install odiff,
so it is safe to use in skip conditions and scripts.
A silent check: unlike find_odiff(), it never offers to install odiff,
so it is safe to use in skip conditions and scripts.