R/update.R
odiffr_cache_path.Rd
Returns the path to the odiffr cache directory where downloaded binaries are stored.
odiffr_cache_path()
Character string with the path to the cache directory.
odiffr_cache_path() #> [1] "/home/runner/.cache/R/odiffr"